# sentry-dingtalk
sentry dingtalk notification plugin


## Extensions for Sentry. Includes Slack, GitHub, and HipChat.

### Install the package via ``pip``::

    ```pip install sentry-dingtalk```

### Run migrations after installation is complete

    ```sentry upgrade```